    '----
    ' Running an Ordered List in Enterprise Guide
    '----
    '	Language:  Windows/VB Script
    '----
    ' Summary:
    '	This script will demonstrate how to access and run an Ordered List
    ' that is contained in an Enterprise Guide project.
    '----
    '	Process:
    ' This script first opens the Enterprise Guide application and 
    ' identifies the project that should be opened.  To run this script
    ' for your project, find the project name: 	ProjectWithOrderedList.egp
    ' Modify that path and filename to point to your project file.
    ' 
    ' The script will look through the project and find the Container Collection.
    '	The Ordered Lists are stored within the Container Collection for the project.
    ' Ordered Lists are identified as type "5" container objects.  This script looks
    ' for a container of type "5" and runs each of the processes stored in the 
    ' Ordered List.
    '----
    ' Additional Note:
    ' A message box has been commented out in this script.  If the line of code
    ' that creates the message box is uncommented, the message box will display
    ' the name and the type ID associated with each type of object in the container
    ' collection for a project.  For Example, Ordered Lists are type "5" objects.
    ' Other objects will have different numerical identifiers.
    '
    ' This information can be helpful if you have a need to access other types of 
    ' objects in the container collection.
    ' 	Process Flows:   0
    '		Publish Action:  1
    '		Document Builder 2
    '		Report Builder   3
    '		Scheduled Items  4
    ' 	Ordered Lists:   5
    '----


    '----
    ' Set up the variables that we will need in this script
    '----

	Dim app		'The application variable
	Dim prj		'The project to read		
	Dim container     'The Container Collection for the project
	Dim orderedList	'The Ordered List in the Container
	Dim n			'Counter for objects in the container
	Dim p			'Counter for items in the Ordered List
	Dim msgNL		'NewLine String

	msgNL=chr(13)
	
    '----
    ' Get project filename
    '----
    ' Start up SAS Enterprise Guide using the project name
    '----

	' The EG 4 Application Variable
    Set app = WScript.CreateObject("SASEGObjectModel.Application.4.2")

	' The project to open.  Modify the file path and name to open your project.
    Set prj = app.Open("C:\SAS\EG\Samples\4.2\ProjectWithOrderedList.egp","")

	' The Container Collection within the project contains the Ordered Lists.
	' This statement gets the Container Collection.
    Set container = prj.ContainerCollection

	' Now, loop through all of the objects in the Container Collection looking 
	' for an Ordered List.  An object that is of type '5' is an Ordered List.
	' When an Ordered List is found, run it.

	' Loop through the Container
	For n=0 to (container.Count -1)

		' Uncomment the following message box code to see the name and type ID 
		' for each container
	'msgbox("Container Name: " & container(n).Name & " " & msgNL & "Container Type ID: " & container(n).ContainerType )

		' Check the type of the object in the container.
		' If it's type '5', it's an Ordered List.
		if container(n).ContainerType = 5 then

			msgbox("Found an Ordered List")
			' Get the ordered list from the container.
			Set orderedList = container(n).Items

			' Loop through all ordered lists in the collection,
			' and run each of them.
			for p=0 to (orderedList.Count -1)
				msgbox("Running Ordered List Number " &p+1)
				orderedList(p).run
			Next
		end if 
	Next
	msgbox("Done")
